Enum Event

#[non_exhaustive]
pub enum Event { Keymap { format: WEnum<KeymapFormat>, fd: OwnedFd, size: u32, }, Enter { serial: u32, surface: WlSurface, keys: Vec<u8>, }, Leave { serial: u32, surface: WlSurface, }, Key { serial: u32, time: u32, key: u32, state: WEnum<KeyState>, }, Modifiers { serial: u32, mods_depressed: u32, mods_latched: u32, mods_locked: u32, group: u32, }, RepeatInfo { rate: i32, delay: i32, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Keymap

keyboard mapping

This event provides a file descriptor to the client which can be memory-mapped in read-only mode to provide a keyboard mapping description.

From version 7 onwards, the fd must be mapped with MAP_PRIVATE by the recipient, as MAP_SHARED may fail.

Fields

format: WEnum<KeymapFormat>

keymap format

fd: OwnedFd

keymap file descriptor

size: u32

keymap size, in bytes



Enter

enter event

Notification that this seat’s keyboard focus is on a certain surface.

The compositor must send the wl_keyboard.modifiers event after this event.

In the wl_keyboard logical state, this event sets the active surface to the surface argument and the keys currently logically down to the keys in the keys argument. The compositor must not send this event if the wl_keyboard already had an active surface immediately before this event.

Clients should not use the list of pressed keys to emulate key-press events. The order of keys in the list is unspecified.

Fields

serial: u32

serial number of the enter event

surface: WlSurface

surface gaining keyboard focus

keys: Vec<u8>

the keys currently logically down



Leave

leave event

Notification that this seat’s keyboard focus is no longer on a certain surface.

The leave notification is sent before the enter notification for the new focus.

In the wl_keyboard logical state, this event resets all values to their defaults. The compositor must not send this event if the active surface of the wl_keyboard was not equal to the surface argument immediately before this event.

Fields

serial: u32

serial number of the leave event

surface: WlSurface

surface that lost keyboard focus



Key

key event

A key was pressed or released. The time argument is a timestamp with millisecond granularity, with an undefined base.

The key is a platform-specific key code that can be interpreted by feeding it to the keyboard mapping (see the keymap event).

If this event produces a change in modifiers, then the resulting wl_keyboard.modifiers event must be sent after this event.

In the wl_keyboard logical state, this event adds the key to the keys currently logically down (if the state argument is pressed) or removes the key from the keys currently logically down (if the state argument is released). The compositor must not send this event if the wl_keyboard did not have an active surface immediately before this event. The compositor must not send this event if state is pressed (resp. released) and the key was already logically down (resp. was not logically down) immediately before this event.

Since version 10, compositors may send key events with the “repeated” key state when a wl_keyboard.repeat_info event with a rate argument of 0 has been received. This allows the compositor to take over the responsibility of key repetition.

Fields

serial: u32

serial number of the key event

time: u32

timestamp with millisecond granularity

key: u32

key that produced the event

state: WEnum<KeyState>

physical state of the key



Modifiers

modifier and group state

Notifies clients that the modifier and/or group state has changed, and it should update its local state.

The compositor may send this event without a surface of the client having keyboard focus, for example to tie modifier information to pointer focus instead. If a modifier event with pressed modifiers is sent without a prior enter event, the client can assume the modifier state is valid until it receives the next wl_keyboard.modifiers event. In order to reset the modifier state again, the compositor can send a wl_keyboard.modifiers event with no pressed modifiers.

In the wl_keyboard logical state, this event updates the modifiers and group.

Fields

serial: u32

serial number of the modifiers event

mods_depressed: u32

depressed modifiers

mods_latched: u32

latched modifiers

mods_locked: u32

locked modifiers

group: u32

keyboard layout



RepeatInfo

repeat rate and delay

Informs the client about the keyboard’s repeat rate and delay.

This event is sent as soon as the wl_keyboard object has been created, and is guaranteed to be received by the client before any key press event.

Negative values for either rate or delay are illegal. A rate of zero will disable any repeating (regardless of the value of delay).

This event can be sent later on as well with a new value if necessary, so clients should continue listening for the event past the creation of wl_keyboard.

Only available since version 4 of the interface

Fields

rate: i32

the rate of repeating keys in characters per second

delay: i32

delay in milliseconds since key down until repeating starts

Implementations



impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message