Enum KeyState

#[non_exhaustive]
#[repr(u32)]
pub enum KeyState { Released = 0, Pressed = 1, Repeated = 2, }
Available on crate feature wayland and Linux only.
physical key state

Describes the physical state of a key that produced the key event.

Since version 10, the key can be in a “repeated” pseudo-state which means the same as “pressed”, but is used to signal repetition in the key event.

The key may only enter the repeated state after entering the pressed state and before entering the released state. This event may be generated multiple times while the key is down.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Released = 0

key is not pressed



Pressed = 1

key is pressed



Repeated = 2

key was repeated