Enum KeymapFormat
#[non_exhaustive]#[repr(u32)]pub enum KeymapFormat {
NoKeymap = 0,
XkbV1 = 1,
}Available on crate feature
wayland and Linux only.Expand description
keyboard mapping format
This specifies the format of the keymap provided to the client with the wl_keyboard.keymap event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoKeymap = 0
no keymap; client must understand how to interpret the raw keycode
XkbV1 = 1
libxkbcommon compatible, null-terminated string; to determine the xkb keycode, clients must add 8 to the key event keycode