Struct WlKeyboard
pub struct WlKeyboard { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
keyboard input device
The wl_keyboard interface represents one or more keyboards associated with a seat.
Each wl_keyboard has the following logical state:
- an active surface (possibly null),
- the keys currently logically down,
- the active modifiers,
- the active group.
By default, the active surface is null, the keys currently logically down are empty, the active modifiers and the active group are 0.
See also the Event enum for this interface.
Implementations
impl WlKeyboard
impl WlKeyboard
pub fn release(&self)
pub fn release(&self)
release the keyboard object